# Colored Terminal
	* Python support for colored text in terminal

```python
from cterminal.cio import *

cprint(style.RED + "test")
```

## Supported

| Platform      | Colors        |
| ------------- | ------------- |
| Windows		| Yes			|


| Colors        |
| ------------- |
| BLACK      	|
| RED      		|
| GREEN 		|
| YELLOW		|
| BLUE			|
| MAGENTA		|
| CYAN			|
| WHITE			|
| UNDERLINE		|
